package com.qmth.paper.library.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.boot.tools.excel.ExcelReader;
import com.qmth.boot.tools.excel.enums.ExcelType;
import com.qmth.paper.library.business.entity.ExamCourse;
import com.qmth.paper.library.business.entity.PaperScanTask;
import com.qmth.paper.library.business.mapper.ExamStudentMapper;
import com.qmth.paper.library.business.service.ExamCourseService;
import com.qmth.paper.library.business.service.ExamStudentService;
import com.qmth.paper.library.business.service.PaperLibraryService;
import com.qmth.paper.library.business.service.PaperScanTaskService;
import com.qmth.paper.library.common.bean.dto.syssetting.SimpleObject;
import com.qmth.paper.library.common.contant.SysSettingConstant;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.ExamStudent;
import com.qmth.paper.library.common.entity.SysUser;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.enums.RecognitionTypeEnum;
import com.qmth.paper.library.common.enums.StoreTypeEnum;
import com.qmth.paper.library.common.service.CommonCacheService;
import com.qmth.paper.library.common.util.ServletUtil;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 学校id 服务实现类
 * </p>
 *
 * @author wangliang
 * @since 2021-08-02
 */
@Service
public class ExamStudentServiceImpl extends ServiceImpl<ExamStudentMapper, ExamStudent> implements ExamStudentService {
    @Resource
    private ExamCourseService examCourseService;
    @Resource
    private PaperLibraryService paperLibraryService;
    @Resource
    private PaperScanTaskService paperScanTaskService;
    @Resource
    private CommonCacheService commonCacheService;

    @Override
    public IPage<ExamStudent> findStudentPage(Long examId, String courseCode, String collegeName, String majorName, String clazzName, String queryParams, int pageNumber, int pageSize) {
        queryParams = SystemConstant.translateSpecificSign(queryParams);
        return this.baseMapper.findStudentPage(new Page<>(pageNumber, pageSize), examId, courseCode, collegeName, majorName, clazzName, queryParams);
    }

    @Transactional
    @Override
    public void saveBasicStudent(ExamStudent examStudent) {
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        // 验证
        ExamStudent byStudentCode = this.getByExamIdAndCourseCodeAndStudentCode(examStudent.getExamId(), examStudent.getCourseCode(), examStudent.getStudentCode());
        if (examStudent.getId() == null) {
            if (StringUtils.isBlank(examStudent.getStudentCode())) {
                throw ExceptionResultEnum.ERROR.exception("学号必填");
            }
            if (StringUtils.isBlank(examStudent.getStudentName())) {
                throw ExceptionResultEnum.ERROR.exception("姓名必填");
            }
            if (StringUtils.isBlank(examStudent.getCourseCode())) {
                throw ExceptionResultEnum.ERROR.exception("课程代码必填");
            }
            if (StringUtils.isBlank(examStudent.getCourseName())) {
                throw ExceptionResultEnum.ERROR.exception("课程名称必填");
            }

            // 校验是否设置了存储方式
            SimpleObject recognitionTypeSimpleObject = commonCacheService.getSysSetting(sysUser.getSchoolId()).get(SysSettingConstant.RECOGNITION_TYPE);
            if (StringUtils.isBlank(recognitionTypeSimpleObject.getValue())) {
                throw ExceptionResultEnum.ERROR.exception("识别方式未设置");
            }
            SimpleObject storeTypeSimpleObject = commonCacheService.getSysSetting(sysUser.getSchoolId()).get(SysSettingConstant.STORE_TYPE);
            if (StringUtils.isBlank(storeTypeSimpleObject.getValue())) {
                throw ExceptionResultEnum.ERROR.exception("文件存储方式未设置");
            }
            RecognitionTypeEnum recognitionType = RecognitionTypeEnum.valueOf(recognitionTypeSimpleObject.getValue());
            StoreTypeEnum storeType = StoreTypeEnum.valueOf(storeTypeSimpleObject.getValue());
            if (StoreTypeEnum.ROOM.equals(storeType) && StringUtils.isBlank(examStudent.getExamRoom())) {
                throw ExceptionResultEnum.ERROR.exception("考场必填");
            }
            if (StoreTypeEnum.CLASS.equals(storeType) && StringUtils.isBlank(examStudent.getClassName())) {
                throw ExceptionResultEnum.ERROR.exception("班级必填");
            }
            if (byStudentCode != null) {
                throw ExceptionResultEnum.ERROR.exception(String.format("学号[%s]在课程%s（%s）下已存在", examStudent.getStudentCode(), examStudent.getCourseName(), examStudent.getCourseCode()));
            }
            examStudent.setId(SystemConstant.getDbUuid());
            examStudent.setSchoolId(sysUser.getSchoolId());
            examStudent.setCreateId(sysUser.getId());
            examStudent.setCreateTime(System.currentTimeMillis());
            boolean save = this.save(examStudent);

            if (save) {
                // 保存课程
                examCourseService.saveStudentCourse(examStudent.getExamId(), examStudent);
                // 保存任务（存在则更新考生数量）
                paperScanTaskService.addScanTask(examStudent.getExamId(), recognitionType, storeType, examStudent);
            }
        } else {
            if (byStudentCode != null && !examStudent.getId().equals(byStudentCode.getId())) {
                throw ExceptionResultEnum.ERROR.exception(String.format("学号[%s]在课程%s（%s）下已存在", examStudent.getStudentCode(), examStudent.getCourseName(), examStudent.getCourseCode()));
            }
            examStudent.setId(examStudent.getId());
            examStudent.setEnable(true);
            examStudent.setUpdateId(sysUser.getId());
            examStudent.setUpdateTime(System.currentTimeMillis());
            this.updateById(examStudent);
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Boolean removeBasicStudentBatch(List<Long> ids) {
        if (CollectionUtils.isEmpty(ids)) {
            throw ExceptionResultEnum.ERROR.exception("请选择删除的数据");
        }
        List<ExamStudent> examStudentList = this.listByIds(ids);
        if (CollectionUtils.isNotEmpty(examStudentList)) {
            List<String> studentCodes = examStudentList.stream().filter(m -> m.getBindCount() > 0).map(ExamStudent::getStudentCode).collect(Collectors.toList());
            if (CollectionUtils.isNotEmpty(studentCodes)) {
                throw ExceptionResultEnum.ERROR.exception("有考生已绑定图片，学号：" + String.join(",", studentCodes));
            }
        }
        // 删除基础学生
        this.removeByIds(ids);
        Map<String, String> stringMap = examStudentList.stream().collect(Collectors.toMap(ExamStudent::getCourseCode, ExamStudent::getCourseName, (oldValue, newValue) -> oldValue));
        for (Map.Entry<String, String> entry : stringMap.entrySet()) {
            Long examId = examStudentList.get(0).getExamId();
            int count = this.countByExamIdAndCourseCode(examId, entry.getKey());
            PaperScanTask paperScanTask = paperScanTaskService.getByExamIdAndCourseCode(examId, entry.getKey());
            if (count == 0) {
                // 删除课程
                examCourseService.removeByExamIdAndCourseCode(examId, entry.getKey());
                // 删除任务
                if (paperScanTask != null) {
                    paperScanTaskService.removeById(paperScanTask.getId());
                }
            } else {
                if (paperScanTask != null) {
                    paperScanTaskService.updateStudentCount(paperScanTask);
                }
            }
        }
        return true;
    }

    @Override
    public ExamStudent getByExamIdAndCourseCodeAndStudentCode(Long examId, String courseCode, String studentCode) {
        QueryWrapper<ExamStudent> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ExamStudent::getExamId, examId)
                .eq(ExamStudent::getCourseCode, courseCode)
                .eq(ExamStudent::getStudentCode, studentCode);
        return this.getOne(queryWrapper);
    }

    @Transactional
    @Override
    public void dataImport(Long semesterId, Long examId, MultipartFile file) {
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        // 校验是否设置了存储方式
        SimpleObject recognitionTypeSimpleObject = commonCacheService.getSysSetting(sysUser.getSchoolId()).get(SysSettingConstant.RECOGNITION_TYPE);
        if (StringUtils.isBlank(recognitionTypeSimpleObject.getValue())) {
            throw ExceptionResultEnum.ERROR.exception("识别方式未设置");
        }
        SimpleObject storeTypeSimpleObject = commonCacheService.getSysSetting(sysUser.getSchoolId()).get(SysSettingConstant.STORE_TYPE);
        if (StringUtils.isBlank(storeTypeSimpleObject.getValue())) {
            throw ExceptionResultEnum.ERROR.exception("文件存储方式未设置");
        }
        RecognitionTypeEnum recognitionType = RecognitionTypeEnum.valueOf(recognitionTypeSimpleObject.getValue());
        StoreTypeEnum storeType = StoreTypeEnum.valueOf(storeTypeSimpleObject.getValue());

        try {
            ExcelReader excelReader = ExcelReader.create(ExcelType.XLSX, file.getInputStream(), 0);
            List<ExamStudent> basicStudentList = excelReader.getObjectList(ExamStudent.class);
            // 校验excel内容
            validStudentData(semesterId, examId, basicStudentList, storeType, sysUser);
            // 保存课程
            List<ExamCourse> examCourses = examCourseService.saveBatchStudentCourse(examId, basicStudentList);
            // 新建任务
            paperScanTaskService.addBatchScanTask(examId, recognitionType, storeType, examCourses, basicStudentList);
            for (ExamCourse examCourse : examCourses) {
                this.removeByExamIdAndCourseCode(examId, examCourse.getCourseCode());
            }
            // 保存学生
            this.saveBatch(basicStudentList);
        } catch (IOException e) {
            throw new RuntimeException(e);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public void updateBindCount(Long studentId) {
        UpdateWrapper<ExamStudent> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda().set(ExamStudent::getBindCount, paperLibraryService.countByStudentId(studentId))
                .eq(ExamStudent::getId, studentId);
        this.update(updateWrapper);
    }

    @Override
    public void removeByExamIdAndCourseCode(Long examId, String courseCode) {
        QueryWrapper<ExamStudent> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ExamStudent::getExamId, examId)
                .eq(ExamStudent::getCourseCode, courseCode);
        this.remove(queryWrapper);
    }

    @Override
    public int countByExamIdAndCourseCode(Long examId, String courseCode) {
        QueryWrapper<ExamStudent> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ExamStudent::getExamId, examId)
                .eq(ExamStudent::getCourseCode, courseCode);
        return this.count(queryWrapper);
    }

    /**
     * 学生保存公共方法
     */
    private void validStudentData(Long semesterId, Long examId, List<ExamStudent> basicStudentList, StoreTypeEnum storeType, SysUser sysUser) {
        Map<String, String> courseMap = new HashMap<>();
        Map<String, List<String>> studentCodeMap = new HashMap<>();
        for (ExamStudent basicStudent : basicStudentList) {
            StringJoiner errorMsg = new StringJoiner("；");
            if (StringUtils.isBlank(basicStudent.getStudentCode())) {
                errorMsg.add("学号必填");
            }
            if (StringUtils.isBlank(basicStudent.getStudentName())) {
                errorMsg.add("姓名必填");
            }
            if (StringUtils.isBlank(basicStudent.getCourseCode())) {
                errorMsg.add("课程代码必填");
            }
            if (StringUtils.isBlank(basicStudent.getCourseName())) {
                errorMsg.add("课程名称必填");
            }
            if (StoreTypeEnum.ROOM.equals(storeType) && StringUtils.isBlank(basicStudent.getExamRoom())) {
                errorMsg.add("考场必填");
            }
            if (StoreTypeEnum.CLASS.equals(storeType) && StringUtils.isBlank(basicStudent.getClassName())) {
                errorMsg.add("班级必填");
            }
            if (courseMap.containsKey(basicStudent.getCourseCode())) {
                if (!basicStudent.getCourseName().equals(courseMap.get(basicStudent.getCourseCode()))) {
                    errorMsg.add("课程代码已存在课程名称[" + courseMap.get(basicStudent.getCourseCode()) + "]");
                }
            }
            // 考生在同课程下重复
            if (studentCodeMap.containsKey(basicStudent.getCourseCode())) {
                List<String> studentCodeList = studentCodeMap.get(basicStudent.getCourseCode());
                if (CollectionUtils.isEmpty(studentCodeList)) {
                    studentCodeMap.put(basicStudent.getCourseCode(), new ArrayList<>());
                } else {
                    if (studentCodeList.contains(basicStudent.getStudentCode())) {
                        errorMsg.add("学号在同课程下已存在");
                    } else {
                        studentCodeList.add(basicStudent.getStudentCode());
                        studentCodeMap.put(basicStudent.getCourseCode(), studentCodeList);
                    }
                }
            }

            if(StringUtils.isNotBlank(errorMsg.toString())){
                throw ExceptionResultEnum.ERROR.exception(errorMsg.toString());
            }

            basicStudent.setId(SystemConstant.getDbUuid());
            basicStudent.setSchoolId(sysUser.getSchoolId());
            basicStudent.setSemesterId(semesterId);
            basicStudent.setExamId(examId);
            basicStudent.setCreateId(sysUser.getId());
            basicStudent.setCreateTime(System.currentTimeMillis());
        }
    }
}
