package com.qmth.paper.library.business.templete.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.common.collect.Lists;
import com.qmth.boot.api.exception.ApiException;
import com.qmth.paper.library.business.bean.result.DocManageDetailResult;
import com.qmth.paper.library.business.entity.PaperLibrary;
import com.qmth.paper.library.business.entity.PaperScanTask;
import com.qmth.paper.library.business.service.*;
import com.qmth.paper.library.business.templete.service.TaskLogicService;
import com.qmth.paper.library.common.bean.dto.excel.DescribeImportDto;
import com.qmth.paper.library.common.bean.dto.excel.SysOrgImportDto;
import com.qmth.paper.library.common.bean.dto.excel.SysUserImportDto;
import com.qmth.paper.library.common.bean.params.DownLoadPaperParams;
import com.qmth.paper.library.common.config.DictionaryConfig;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.*;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.enums.StoreTypeEnum;
import com.qmth.paper.library.common.enums.UploadFileEnum;
import com.qmth.paper.library.common.service.BasicSchoolService;
import com.qmth.paper.library.common.service.BasicSemesterService;
import com.qmth.paper.library.common.service.SysOrgService;
import com.qmth.paper.library.common.service.SysUserService;
import com.qmth.paper.library.common.util.*;
import com.qmth.paper.library.common.util.excel.ExcelError;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.LinkedMultiValueMap;

import javax.annotation.Resource;
import java.io.*;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @Description: 任务处理逻辑impl
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/3/29
 */
@Service
public class TaskLogicServiceImpl implements TaskLogicService {
    private final static Logger log = LoggerFactory.getLogger(TaskLogicServiceImpl.class);

    @Resource
    private DictionaryConfig dictionaryConfig;
    @Resource
    private SysOrgService sysOrgService;
    @Resource
    private SysUserService sysUserService;
    @Resource
    private DocManageService docManageService;
    @Resource
    private PaperLibraryCommonService paperLibraryCommonService;
    @Resource
    private FileStoreUtil fileStoreUtil;
    @Resource
    private PaperLibraryService paperLibraryService;
    @Resource
    private PaperScanTaskService paperScanTaskService;
    @Resource
    private ExamStudentService examStudentService;
    @Resource
    private BasicSchoolService basicSchoolService;
    @Resource
    private BasicSemesterService basicSemesterService;
    @Resource
    private BasicExamService basicExamService;

    @Transactional
    @Override
    public Map<String, Object> executeImportSysOrgLogic(Map<String, Object> map) throws IOException, NoSuchFieldException {
        InputStream inputStream = (InputStream) map.get("inputStream");
        List<LinkedMultiValueMap<Integer, Object>> finalList = ExcelUtil.excelReader(inputStream, Lists.newArrayList(SysOrgImportDto.class, DescribeImportDto.class), (finalExcelList, finalColumnNameList, finalExcelErrorList) -> finalExcelList);
        List<String> orgInfoList = new ArrayList<>();
        for (int i = 0; i < finalList.size(); i++) {
            LinkedMultiValueMap<Integer, Object> excelMap = finalList.get(i);
            List<Object> sysOrgImportDtoList = excelMap.get(i);
            assert sysOrgImportDtoList != null;
            if (sysOrgImportDtoList.get(0) instanceof DescribeImportDto) {
                continue;
            }
            map.put("dataCount", sysOrgImportDtoList.size());
            //  处理机构
            if (sysOrgImportDtoList.get(0) instanceof SysOrgImportDto) {
                List<SysOrgImportDto> datasource = sysOrgImportDtoList.stream().map(e -> {
                    SysOrgImportDto sysOrgImportDto = new SysOrgImportDto();
                    BeanUtils.copyProperties(e, sysOrgImportDto);
                    return sysOrgImportDto;
                }).collect(Collectors.toList());
                if (datasource.size() > 0) {
                    datasource.forEach(e -> orgInfoList.add(e.getName()));
                }
            }
        }
        if (orgInfoList.size() > 0) {
            SysUser requestUser = (SysUser) map.get(SystemConstant.SYS_USER);
            sysOrgService.createOrGetOrgByOrgInfo(orgInfoList, requestUser);
        }
        return map;
    }

    @Transactional
    @Override
    public Map<String, Object> executeImportSysUserLogic(Map<String, Object> map) throws Exception {
        InputStream inputStream = (InputStream) map.get("inputStream");
        List<LinkedMultiValueMap<Integer, Object>> finalList = ExcelUtil.excelReader(inputStream, Lists.newArrayList(SysUserImportDto.class, DescribeImportDto.class), (finalExcelList, finalColumnNameList, finalExcelErrorList) -> {
            List<ExcelError> excelErrorTemp = new ArrayList<>();
            Map<String, SysUserImportDto> checkDtoMap = new HashMap<>();

            for (int i = 0; i < finalExcelList.size(); i++) {
                LinkedMultiValueMap<Integer, Object> excelMap = finalExcelList.get(i);
                List<Object> sysUserImportDtoList = excelMap.get(i);
                assert sysUserImportDtoList != null;
                if (sysUserImportDtoList.get(0) instanceof DescribeImportDto) {
                    continue;
                }
                map.put("dataCount", sysUserImportDtoList.size());
                List<SysUserImportDto> duplicateData = new ArrayList<>();
                for (int y = 0; y < Objects.requireNonNull(sysUserImportDtoList).size(); y++) {
                    SysUserImportDto sysUserImportDto = (SysUserImportDto) sysUserImportDtoList.get(y);
                    String name = StringUtils.isNotBlank(sysUserImportDto.getName()) ? sysUserImportDto.getName().trim() : null;
                    String loginName = StringUtils.isNotBlank(sysUserImportDto.getLoginName()) ? sysUserImportDto.getLoginName().trim() : null;
//                    String phoneNumber = StringUtils.isNotBlank(sysUserImportDto.getPhoneNumber()) ? sysUserImportDto.getPhoneNumber().trim() : null;
                    String orgName = StringUtils.isNotBlank(sysUserImportDto.getOrgName()) ? sysUserImportDto.getOrgName().trim() : null;
                    String roleName = StringUtils.isNotBlank(sysUserImportDto.getRoleName()) ? sysUserImportDto.getRoleName().trim() : null;

                    if (checkDtoMap.containsKey(loginName)) {
                        SysUserImportDto primaryCell = checkDtoMap.get(loginName);
                        String priName = primaryCell.getName();
//                        String priPhoneNumber = primaryCell.getPhoneNumber();
                        String priOrgName = primaryCell.getOrgName();
                        if (!Objects.equals(priName, name)) {
                            throw ExceptionResultEnum.ERROR.exception("【用户名】 ：" + loginName + "的用户存在不同的名称");
                        }
//                        if (!Objects.equals(priPhoneNumber, phoneNumber)) {
//                            throw ExceptionResultEnum.ERROR.exception("【账号】 ：" + loginName + "的用户存在不同的手机号");
//                        }
                        if (!Objects.equals(priOrgName, orgName)) {
                            throw ExceptionResultEnum.ERROR.exception("【用户名】 ：" + loginName + "的用户存在不同的组织架构");
                        }
                        String priRoleName = primaryCell.getRoleName();
                        if (SystemConstant.strNotNull(roleName)) {
                            priRoleName = priRoleName + SystemConstant.COMMA + roleName;
                            primaryCell.setRoleName(priRoleName);
                        }
                        duplicateData.add(sysUserImportDto);
                    } else {
                        checkDtoMap.put(loginName, sysUserImportDto);
                    }

                    excelErrorTemp.addAll(ExcelUtil.checkExcelField(sysUserImportDto, y, i));
                    if (Objects.isNull(loginName) || loginName.length() > 30 || !loginName.matches(SystemConstant.REGULAR_EXPRESSION_OF_CODE)) {
                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[账号]不符合输入规范"));
                    }
                    if (Objects.isNull(name) || name.length() > 30) {
                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[姓名]不符合输入规范"));
                    }
//                    if (Objects.nonNull(phoneNumber) && !phoneNumber.matches(SystemConstant.REGULAR_EXPRESSION_OF_PHONE)) {
//                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[电话号码]不符合输入规范"));
//                    }
                }
                sysUserImportDtoList.removeAll(duplicateData);
            }
            if (excelErrorTemp.size() > 0) {
                throw ExceptionResultEnum.ERROR.exception(JSONObject.toJSONString(excelErrorTemp));
            }
            return finalExcelList;
        });
        return sysUserService.executeSysUserImportLogic(finalList, map);
    }


    @Override
    public Map<String, Object> executeDownloadPaperLogic(Map<String, Object> map) {
        List<File> sourceFileList = new ArrayList<>();
        File zipFile = null;
        String rootPath = null;
        String zipLocalRootPath = null;
        try {
            TBTask tbTask = (TBTask) map.get(SystemConstant.TASK);
            DownLoadPaperParams downLoadPaperParams = JSON.parseObject(tbTask.getRemark(), DownLoadPaperParams.class);

            PaperScanTask paperScanTask = paperScanTaskService.getById(downLoadPaperParams.getPaperScanTaskId());

            BasicSchool basicSchool = basicSchoolService.getById(paperScanTask.getSchoolId());
            BasicExam basicExam = basicExamService.getById(paperScanTask.getExamId());
            BasicSemester basicSemester = basicSemesterService.getById(basicExam.getSemesterId());
            String courseNameCode = String.format("%s(%s)", paperScanTask.getCourseName(), paperScanTask.getCourseCode());

            List<DocManageDetailResult> docManageDetailResults = docManageService.listDetail(downLoadPaperParams);
            rootPath = fileStoreUtil.buildPath(UploadFileEnum.DOWNLOAD, true, String.valueOf(System.currentTimeMillis()));
            String dirName = SystemConstant.getUuid() + SystemConstant.ZIP_SUFFIX;
            zipFile = new File(rootPath + dirName);
            if (!zipFile.getParentFile().exists()) {
                zipFile.getParentFile().mkdirs();
            }
            zipLocalRootPath = rootPath + File.separator + basicSchool.getName() + File.separator + basicSemester.getName() + File.separator + basicExam.getName() + File.separator + courseNameCode;
            Map<Long, Integer> successMap = new HashMap<>();
            Map<Long, Integer> errorMap = new HashMap<>();
            for (DocManageDetailResult docManageDetailResult : docManageDetailResults) {
                Long studentId = docManageDetailResult.getStudentId();
                successMap.putIfAbsent(studentId, 0);
                errorMap.putIfAbsent(studentId, 0);
                QueryWrapper<PaperLibrary> queryWrapper = new QueryWrapper<>();
                queryWrapper.lambda().eq(PaperLibrary::getPaperScanTaskId, downLoadPaperParams.getPaperScanTaskId())
                        .eq(PaperLibrary::getStudentId, studentId);
                List<PaperLibrary> paperLibraryList = paperLibraryService.list(queryWrapper);

                ExamStudent examStudent = examStudentService.getById(studentId);
                for (PaperLibrary paperLibrary : paperLibraryList) {
                    List<JSONObject> objectList = JSON.parseArray(paperLibrary.getPath(), JSONObject.class);
                    for (JSONObject jsonObject : objectList) {
                        try {
                            String imagePath = zipLocalRootPath;
                            if (StoreTypeEnum.ROOM.equals(paperScanTask.getStoreType())) {
                                imagePath = imagePath + File.separator + examStudent.getExamRoom();
                            } else if (StoreTypeEnum.CLASS.equals(paperScanTask.getStoreType())) {
                                imagePath = imagePath + File.separator + examStudent.getClassName();
                            } else if (StoreTypeEnum.COURSE.equals(paperScanTask.getStoreType())) {
                                imagePath = imagePath + File.separator + examStudent.getStudentCode();
                            }
                            File file = paperLibraryCommonService.downloadFile(imagePath, jsonObject.getString(SystemConstant.PATH), jsonObject.getString(SystemConstant.UPLOAD_TYPE), jsonObject.getString(SystemConstant.TYPE));
                            sourceFileList.add(file);
                            successMap.put(studentId, successMap.get(studentId) + 1);
                        } catch (FileNotFoundException e) {
                            errorMap.put(studentId, successMap.get(studentId) + 1);
                        }
                    }
                }
            }

            if (!CollectionUtils.isEmpty(sourceFileList)) {
                // 生成清单
                createPaperDownloadExcel(rootPath, docManageDetailResults, successMap, errorMap);

                Zip4jUtil.zipEncryptFile(zipFile.getPath(), rootPath, SystemConstant.ZIP_ENCRYPT_PWD);
                String ossDirName = dirName.replaceAll("\\\\", "/");
                JSONObject jsonObject = new JSONObject();
                if (fileStoreUtil.isOssStore()) {
                    fileStoreUtil.fileUpload(ossDirName, zipFile);
                    jsonObject.put(SystemConstant.PATH, ossDirName);
                    jsonObject.put(SystemConstant.TYPE, SystemConstant.OSS);
                } else {
                    jsonObject.put(SystemConstant.TYPE, SystemConstant.LOCAL);
                    jsonObject.put(SystemConstant.PATH, rootPath + ossDirName);
                }
                jsonObject.put(SystemConstant.UPLOAD_TYPE, UploadFileEnum.FILE);
                tbTask.setExportFilePath(jsonObject.toJSONString());
            }
            map.put(SystemConstant.SIZE, Objects.nonNull(docManageDetailResults) ? docManageDetailResults.size() : 0);
        } catch (
                Exception e) {
            log.error(SystemConstant.LOG_ERROR, e);
            if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        } finally {
            if (Objects.nonNull(rootPath)) {
                ConvertUtil.delFolder(rootPath);
            }
            if (Objects.nonNull(dictionaryConfig.sysDomain()) && fileStoreUtil.isOssStore() && Objects.nonNull(zipFile)) {
                zipFile.delete();
            }
        }
        return map;
    }

    /**
     * 生成清单
     *
     * @param zipLocalRootPath 路径
     * @param list             数据
     * @param successMap
     * @param errorMap
     */
    public void createPaperDownloadExcel(String zipLocalRootPath, List<DocManageDetailResult> list, Map<Long, Integer> successMap, Map<Long, Integer> errorMap) throws IOException {
        String fileName = "下载清单.xlsx";
        XSSFWorkbook wb = new XSSFWorkbook();
        XSSFSheet sheet = wb.createSheet("数据");

        // 表头
        CellStyle headerStyle = wb.createCellStyle();
        headerStyle.setAlignment(HorizontalAlignment.CENTER);
        headerStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        headerStyle.setBorderRight(BorderStyle.THIN);
        headerStyle.setRightBorderColor(IndexedColors.BLACK.getIndex());
        headerStyle.setBorderLeft(BorderStyle.THIN);
        headerStyle.setLeftBorderColor(IndexedColors.BLACK.getIndex());
        headerStyle.setBorderTop(BorderStyle.THIN);
        headerStyle.setTopBorderColor(IndexedColors.BLACK.getIndex());
        headerStyle.setBorderBottom(BorderStyle.THIN);
        headerStyle.setBottomBorderColor(IndexedColors.BLACK.getIndex());
        // 背景颜色
        headerStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);
        headerStyle.setFillForegroundColor(IndexedColors.GREY_80_PERCENT.getIndex());
        Font font = wb.createFont();
        font.setFontHeightInPoints((short) 12);
        font.setFontName("宋体");
        font.setColor(IndexedColors.WHITE.getIndex());
        headerStyle.setFont(font);

        // 数据
        XSSFCellStyle dataStyle = wb.createCellStyle();
        dataStyle.setAlignment(HorizontalAlignment.CENTER);
        dataStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        dataStyle.setBorderRight(BorderStyle.THIN);
        dataStyle.setRightBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setBorderLeft(BorderStyle.THIN);
        dataStyle.setLeftBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setBorderTop(BorderStyle.THIN);
        dataStyle.setTopBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setBorderBottom(BorderStyle.THIN);
        dataStyle.setBottomBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);
        // 背景颜色
        dataStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
        font = wb.createFont();
        font.setFontHeightInPoints((short) 10);
        font.setFontName("宋体");
        dataStyle.setFont(font);

        // 锁定样式
        XSSFCellStyle lockStyle = wb.createCellStyle();
        lockStyle.setLocked(true);//设置锁定

        // 未锁定样式
        XSSFCellStyle unlockStyle = wb.createCellStyle();
        unlockStyle.setLocked(false);//设置未锁定

        XSSFRow headRow = sheet.createRow(0);
        // 表头
        String[] fieldsNameList = {"学生姓名", "学号", "专业", "班级", "课程", "任课老师", "教学班", "绑定图片数量（张）", "下载成功数量（页）", "下载失败（页）"};
        for (int i = 0; i < fieldsNameList.length; i++) {
            XSSFCell cell = headRow.createCell(i);
            cell.setCellValue(fieldsNameList[i]);
            cell.setCellStyle(headerStyle);
        }

        for (int i = 1; i <= list.size(); i++) {
            DocManageDetailResult docManageDetailResult = list.get(i - 1);
            XSSFRow row = sheet.createRow(i);

            XSSFCell cell0 = row.createCell(0);
            cell0.setCellStyle(lockStyle);
            cell0.setCellStyle(dataStyle);
            cell0.setCellValue(docManageDetailResult.getStudentName());

            XSSFCell cell1 = row.createCell(1);
            cell1.setCellStyle(lockStyle);
            cell1.setCellStyle(dataStyle);
            cell1.setCellValue(docManageDetailResult.getStudentCode());

            XSSFCell cell2 = row.createCell(2);
            cell2.setCellStyle(lockStyle);
            cell2.setCellStyle(dataStyle);
            cell2.setCellValue(docManageDetailResult.getMajorName());

            XSSFCell cell3 = row.createCell(3);
            cell3.setCellStyle(lockStyle);
            cell3.setCellStyle(dataStyle);
            cell3.setCellValue(docManageDetailResult.getClassName());

            XSSFCell cell4 = row.createCell(4);
            cell4.setCellStyle(lockStyle);
            cell4.setCellStyle(dataStyle);
            cell4.setCellValue(docManageDetailResult.getCourseName());

            XSSFCell cell5 = row.createCell(5);
            cell5.setCellStyle(lockStyle);
            cell5.setCellStyle(dataStyle);
            cell5.setCellValue(docManageDetailResult.getTeacher());

            XSSFCell cell6 = row.createCell(6);
            cell6.setCellStyle(lockStyle);
            cell6.setCellStyle(dataStyle);
            cell6.setCellValue(docManageDetailResult.getTeachClass());

            XSSFCell cell7 = row.createCell(7);
            cell7.setCellStyle(lockStyle);
            cell7.setCellStyle(dataStyle);
            cell7.setCellValue(docManageDetailResult.getBindCount());

            XSSFCell cell8 = row.createCell(8);
            cell8.setCellStyle(lockStyle);
            cell8.setCellStyle(dataStyle);
            cell8.setCellValue(successMap.get(docManageDetailResult.getStudentId()));

            XSSFCell cell9 = row.createCell(9);
            cell9.setCellStyle(lockStyle);
            cell9.setCellStyle(dataStyle);
            cell9.setCellValue(errorMap.get(docManageDetailResult.getStudentId()));
        }

        for (int i = 0; i < fieldsNameList.length; i++) {
            sheet.autoSizeColumn(i);
            sheet.setColumnWidth(i, sheet.getColumnWidth(i) * 17 / 10);
        }

        // sheet添加保护，这个一定要否则光锁定还是可以编辑的
        sheet.protectSheet(SystemConstant.EXCEL_PROTECT_KEY);

        File file = new File(zipLocalRootPath, fileName);
        FileOutputStream fout = new FileOutputStream(file);
        wb.write(fout);
        fout.close();
    }
}
